AbstractTranslator class abstract
Interface for all translation backends.
Implement this to provide your own translation service.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
translateBatch(
List< String> texts, {required String targetLang, String sourceLang = 'en'}) → Future<Map< String, String> > - Translates a batch of strings.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited